@@ -101,7 +101,7 @@ class NxPyDocs():
         env = Environment(loader=FileSystemLoader(str(template_dir)))
         html_template = env.get_template('html.j2')
         html_output = html_template.render(command = self.command,
-            data_to_template=json.loads(parsed_json))
+            data_to_template=json.dumps(parsed_json))
         with open('%s.html' % self.command, 'w') as f:
             f.write(html_output)
         print(html_output)
@@ -113,7 +113,7 @@ class NxPyDocs():
         env = Environment(loader=FileSystemLoader(str(template_dir)))
         markdown_template = env.get_template('md.j2')
         markdown_output = markdown_template.render(command = self.command,
-            data_to_template=json.loads(parsed_json))
+            data_to_template=json.dumps(parsed_json))
         with open('%s.md' % self.command, 'w') as f:
             f.write(markdown_output)
         print(markdown_output)
@@ -125,7 +125,7 @@ class NxPyDocs():
         env = Environment(loader=FileSystemLoader(str(template_dir)))
         csv_template = env.get_template('csv.j2')
         csv_output = csv_template.render(command = self.command,
-            data_to_template=json.loads(parsed_json),
+            data_to_template=json.dumps(parsed_json),
             hostname=self.hostname)
         with open('%s.csv' % self.command, 'w') as f:
             f.write(csv_output)
@@ -138,7 +138,7 @@ class NxPyDocs():
         env = Environment(loader=FileSystemLoader(str(template_dir)))
         mindmap_template = env.get_template('mindmap.j2')
         mindmap_output = mindmap_template.render(command = self.command,
-            data_to_template=json.loads(parsed_json),
+            data_to_template=json.dumps(parsed_json),
             hostname=self.hostname)
         with open('%s mindmap.md' % self.command, 'w') as f:
             f.write(mindmap_output)
